Change in osmo-bsc[master]: borken: Recover from more TS borken states.

This is merely a historical archive of years 2008-2021, before the migration to mailman3.

A maintained and still updated list archive can be found at https://lists.osmocom.org/hyperkitty/list/gerrit-log@lists.osmocom.org/.

ipse gerrit-no-reply at lists.osmocom.org
Sun May 17 21:23:03 UTC 2020


ipse has uploaded this change for review. ( https://gerrit.osmocom.org/c/osmo-bsc/+/18339 )


Change subject: borken: Recover from more TS borken states.
......................................................................

borken: Recover from more TS borken states.

Change-Id: Ic87c325a73690ede1b81b4d33bac65a1a4beea2d
---
M src/osmo-bsc/timeslot_fsm.c
1 file changed, 16 insertions(+), 3 deletions(-)



  git pull ssh://gerrit.osmocom.org:29418/osmo-bsc refs/changes/39/18339/1

diff --git a/src/osmo-bsc/timeslot_fsm.c b/src/osmo-bsc/timeslot_fsm.c
index f8adfb6..84ffb7f 100644
--- a/src/osmo-bsc/timeslot_fsm.c
+++ b/src/osmo-bsc/timeslot_fsm.c
@@ -669,9 +669,17 @@
 		}
 
 	case TS_EV_PDCH_ACT_ACK:
-		/* Late PDCH activation ACK is not a crime.
-		 * Just go into the PDCH mode as normal. */
-		osmo_fsm_inst_state_chg(fi, TS_ST_PDCH, 0, 0);
+	case TS_EV_PDCH_ACT_NACK:
+		/* Late PDCH activation ACK/NACK is not a crime.
+		 * Just process them as normal. */
+		ts_fsm_wait_pdch_act(fi, event, data);
+		return;
+
+	case TS_EV_PDCH_DEACT_ACK:
+	case TS_EV_PDCH_DEACT_NACK:
+		/* Late PDCH deactivation ACK/NACK is also not a crime.
+		 * Just process them as normal. */
+		ts_fsm_wait_pdch_deact(fi, event, data);
 		return;
 
 	default:
@@ -827,8 +835,13 @@
 			| S(TS_EV_LCHAN_REQUESTED)
 			| S(TS_EV_LCHAN_UNUSED)
 			| S(TS_EV_PDCH_ACT_ACK)
+			| S(TS_EV_PDCH_ACT_NACK)
+			| S(TS_EV_PDCH_DEACT_ACK)
+			| S(TS_EV_PDCH_DEACT_NACK)
 			,
 		.out_state_mask = 0
+			| S(TS_ST_IN_USE)
+			| S(TS_ST_UNUSED)
 			| S(TS_ST_NOT_INITIALIZED)
 			| S(TS_ST_PDCH)
 			,

-- 
To view, visit https://gerrit.osmocom.org/c/osmo-bsc/+/18339
To unsubscribe, or for help writing mail filters, visit https://gerrit.osmocom.org/settings

Gerrit-Project: osmo-bsc
Gerrit-Branch: master
Gerrit-Change-Id: Ic87c325a73690ede1b81b4d33bac65a1a4beea2d
Gerrit-Change-Number: 18339
Gerrit-PatchSet: 1
Gerrit-Owner: ipse <Alexander.Chemeris at gmail.com>
Gerrit-MessageType: newchange
-------------- next part --------------
An HTML attachment was scrubbed...
URL: <http://lists.osmocom.org/pipermail/gerrit-log/attachments/20200517/86fe8f89/attachment.htm>


More information about the gerrit-log mailing list